@@ -119,7 +119,7 @@ sub run_method {
     my $data        = delete $params{data}          || undef;
     my $timeout     = delete $params{timeout}       || undef;
 
-    croak "unknown parameters to run_method: %params" if %params;
+    croak "unknown parameters to run_method: @{[%params]}" if %params;
 
     my $function = Gearman::Spawner::Util::method2function($class, $method);
 
@@ -192,7 +192,7 @@ sub run_method_background {
     my $method      = delete $params{method}        || croak "need method";
     my $data        = delete $params{data}          || undef;
 
-    croak "unknown parameters to run_method_background: %params" if %params;
+    croak "unknown parameters to run_method_background: @{[%params]}" if %params;
 
     my $function = Gearman::Spawner::Util::method2function($class, $method);
 
